# -*- coding: cp1252 -*-
"""Common filenames and locations for topographic data, meshes and outputs.
"""

from os import sep, environ, getenv, getcwd
from os.path import expanduser
import sys
from time import localtime, strftime, gmtime
from anuga.utilities.polygon import read_polygon, plot_polygons, polygon_area, is_inside_polygon

if sys.platform == 'win32':
    home = getenv('INUNDATIONHOME')
    user = getenv('USERPROFILE')

else:    
    home = getenv('INUNDATIONHOME', sep+'d'+sep+'xrd'+sep+'gem'+sep+'2'+sep+'ramp'+sep+'risk_assessment_methods_project'+sep+'inundation')     
    user = getenv('LOGNAME')
    print 'USER:', user

# INUNDATIONHOME is the inundation directory, not the data directory.
home += sep +'data'

#Making assumptions about the location of scenario data
state = 'new_south_wales'
scenario_dir_name = 'newcastle_tsunami_scenario_2006'

# onshore data provided by NSW LPI, Krishna merged with existing
# PMD data to make 100m DEM
nsw100 = 'dem_utm'

# survey data
offshore_name2 = 'surveyAreaB'
offshore_name3 = 'surveyAreaC'

# AHO data
offshore_name4 = '1000003611export'
offshore_name5 = '1000003613export'
offshore_name6 = '1000003614export'
offshore_name7 = '1000003627export'
offshore_name8 = '1000003628export'
offshore_name9 = 'AHDexport'

#swollen/ all data output
basename = 'source'
codename = 'project_slide.py'

#Derive subdirectories and filenames
local_time = strftime('%Y%m%d_%H%M%S',gmtime()) 
meshdir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'meshes'+sep
datadir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'topographies'+sep
gaugedir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'gauges'+sep
polygondir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'polygons'+sep
boundarydir = home+sep+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'boundaries'+sep
outputdir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'outputs'+sep
outputtimedir = outputdir + local_time + sep
polygondir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'polygons'+sep

gauge_filename = gaugedir + 'newcastle_gauges.csv'
codedir = getcwd()+sep                            
codedirname = codedir + 'project_slide.py'
meshname = outputtimedir + 'mesh_' + basename

# Necessary if using point datasets, rather than grid
nsw_dem_name = datadir + nsw100
offshore_dem_name2 = datadir + offshore_name2
offshore_dem_name3 = datadir + offshore_name3
offshore_dem_name4 = datadir + offshore_name4
offshore_dem_name5 = datadir + offshore_name5
offshore_dem_name6 = datadir + offshore_name6
offshore_dem_name7 = datadir + offshore_name7
offshore_dem_name8 = datadir + offshore_name8
offshore_dem_name9 = datadir + offshore_name9
combined_dem_name   = datadir + 'newcastle_combined_elevation'

###############################
# Domain definitions
###############################

# bounding polygon for study area
polyAll = read_polygon(polygondir+'extentC3.csv')
polyAll_c0 = read_polygon(polygondir+'extent_c0.csv')

print 'Area of bounding polygon', polygon_area(polyAll)/1000000.0

###############################
# Interior region definitions
###############################

# newcastle digitized polygons
poly_local = read_polygon(polygondir+'local2.csv')
poly_newcastle = read_polygon(polygondir+'newcastle.csv')

print 'Area of local polygon', polygon_area(poly_local)/1000000.0
print 'Area of CBD polygon', polygon_area(poly_newcastle)/1000000.0

# region c0
poly_local_c0 = read_polygon(polygondir+'local_c0.csv')
poly_entrance_c0 = read_polygon(polygondir+'entrance.csv')

#plot_polygons([polyAll,poly_local,poly_newcastle],'fig',verbose=True)
###################################################################
# Clipping regions for export to asc and regions for clipping data
###################################################################

# clipping for nsw grid for conversion
eastingmin_nsw = 350390
eastingmax_nsw = 546000
northingmin_nsw = 6253970
northingmax_nsw = 6424600

# clipping for nsw grid for conversion
eastingminc0_nsw = 322440
eastingmaxc0_nsw = 436250
northingminc0_nsw = 6280000
northingmaxc0_nsw = 6410000

poly_surveyclip = read_polygon(polygondir+'surveyclip.csv')

# exporting asc grid for c1
eastingmin1 = 366890
eastingmax1 = 404270
northingmin1 = 6335450
northingmax1 = 6375630

# exporting asc grid for Michelle and for c2
eastingmin2 = 386450
eastingmax2 = 432900
northingmin2 = 6357500
northingmax2 = 6400700

# exporting asc grid - The Entrance
eastingmin0 = 350950
eastingmax0 = 370015
northingmin0 = 6305280
northingmax0 = 6325620

###################################################################
# Slide characteristics
###################################################################

# historical slides
slide_origin_bulli = [370110,6189489]
slide_origin_shovel = [354753,6187397]
#slide_origin_yacaaba = [463012,6334735] original work was actually Birubi
slide_origin_yacaaba = [476465, 6362424]
slide_origin_birubi = [462267,6335100]

# potential slides: these correspond approximately to modelled depths
slide_origin_bulli_b = [405617,6249852]
slide_origin_bulli_c0 = [438583,6308510]
slide_origin_bulli_c1 = [465283,6335210]
slide_origin_bulli_c2 = [483783,6358810]
slide_origin_shovel_b = [396262,6252144]
slide_origin_shovel_c0 = [431683,6311110]
slide_origin_shovel_c1 = [458694,6340352]
slide_origin_shovel_c2 = [475589,6363030]
slide_origin_yacaaba_a = [359796,6190943]
slide_origin_yacaaba_b = [397330,6251857]
slide_origin_yacaaba_c0 = [431283,6312110]
slide_origin_yacaaba_c1 = [459983,6339110]
slide_origin_birubi_a = [362811,6191183]
slide_origin_birubi_b = [403573,6250268]
slide_origin_birubi_c0 = [437183,6309410]
slide_origin_birubi_c2 = [483392,6359044]

#bulli_depth = 2087.0
bulli_depth = 1470.0
bulli_length = 16840.0
bulli_thickness = 424.0
bulli_width = 8860.0
bulli_density = 1.46
bulli_slope = 4.0
bulli_alpha = 126.0 - 90.0

#shovel_depth = 968.0
shovel_depth = 877.0
shovel_length = 13500.0
shovel_thickness = 165.0
shovel_width = 4350.0
shovel_density = 1.49
shovel_slope = 4.0
shovel_alpha = 118.0 - 90.0

#yacaaba_depth = 1119.0
yacaaba_depth = 938.0
yacaaba_length = 4189.0
yacaaba_thickness = 53.0
yacaaba_width = 2898.0
yacaaba_density = 1.48
yacaaba_slope = 2.3
yacaaba_alpha = 133.0 - 90.0
 
birubi_depth = 1320.
birubi_length = 9903.0
birubi_width = 4150.
birubi_density = 1.48
birubi_slope = 3.7
birubi_alpha = 133.0 - 90.0
birubi_thickness = 140.0
